#include "univ.i"
#line 2 "lexyy.cc"

#line 4 "lexyy.cc"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types.
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t;
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)

/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char*) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
__attribute__((unused)) static void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
static YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE*) 0, *yyout = (FILE*) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 124
#define YY_END_OF_BUFFER 125
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[424] =
    {   0,
        0,    0,  119,  119,    0,    0,    0,    0,  125,  123,
      122,  122,    8,  123,  114,    5,  103,  109,  112,  110,
      107,  111,  123,  113,    1,  123,  108,  106,  104,  105,
      117,   96,   96,   96,   96,   96,   96,   96,   96,   96,
       96,   96,   96,   96,   96,   96,   96,   96,   96,   96,
      115,  116,  119,  120,    6,    7,    9,   10,  122,    4,
       98,  118,    2,    1,    3,   99,  100,  102,  101,    0,
       96,   96,   96,   96,   96,   96,   44,   96,   96,   96,
       96,   96,   96,   96,   96,   96,   96,   96,   96,   96,
       96,   96,   96,   28,   17,   25,   96,   96,   96,   96,

       96,   96,   54,   63,   96,   14,   96,   96,   96,   96,
       96,   96,   96,   96,   96,   96,   96,   96,   96,   96,
       96,   96,   96,   96,  119,  120,  120,  121,    6,    7,
        9,   10,    2,    0,   97,   13,   45,   96,   96,   96,
       96,   96,   96,   96,   96,   96,   96,   96,   96,   96,
       96,   96,   96,   96,   96,   96,   27,   96,   96,   96,
       41,   96,   96,   96,   96,   21,   96,   96,   96,   96,
       96,   15,   96,   96,   96,   18,   96,   96,   96,   96,
       96,   82,   96,   96,   96,   51,   96,   12,   96,   36,
       96,   96,   96,   96,   96,   96,   96,   96,   96,   96,

       96,    0,   97,   96,   96,   96,   96,   20,   96,   24,
       96,   96,   96,   96,   96,   96,   96,   96,   96,   96,
       96,   46,   96,   96,   30,   96,   89,   96,   96,   39,
       96,   96,   96,   96,   96,   48,   96,   94,   91,   32,
       93,   96,   11,   66,   96,   96,   96,   42,   96,   96,
       96,   96,   96,   96,   96,   96,   96,   96,   29,   96,
       96,   96,   96,   96,   96,   96,   96,   96,   87,    0,
       96,   26,   96,   96,   96,   68,   96,   96,   96,   96,
       37,   96,   96,   96,   96,   96,   96,   96,   31,   67,
       23,   96,   59,   96,   77,   96,   96,   96,   43,   96,

       96,   96,   96,   96,   96,   96,   96,   92,   96,   96,
       56,   96,   96,   96,   96,   96,   96,   96,   40,   33,
        0,   81,   95,   19,   96,   96,   85,   96,   76,   55,
       96,   65,   96,   52,   96,   96,   96,   47,   96,   78,
       96,   80,   96,   96,   34,   96,   96,   96,   35,   74,
       96,   96,   96,   96,   60,   96,   50,   49,   96,   96,
       96,   57,   53,   64,   96,   96,   96,   22,   96,   96,
       75,   83,   96,   96,   79,   96,   70,   96,   96,   96,
       96,   96,   38,   96,   90,   69,   96,   86,   96,   96,
       96,   88,   96,   96,   61,   96,   16,   96,   72,   71,

       96,   58,   96,   84,   96,   96,   96,   96,   96,   96,
       96,   96,   96,   96,   73,   96,   96,   96,   96,   96,
       96,   62,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    4,    5,    6,    7,    1,    8,    9,
       10,   11,   12,   13,   14,   15,   16,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   18,   19,   20,
       21,   22,   23,    1,   24,   25,   26,   27,   28,   29,
       30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
       40,   41,   42,   43,   44,   45,   46,   47,   48,   49,
        1,    1,    1,    1,   50,    1,   33,   33,   33,   33,

       33,   33,   33,   33,   33,   33,   33,   51,   33,   33,
       33,   33,   52,   33,   53,   33,   33,   33,   33,   33,
       33,   33,   54,    1,   55,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[56] =
    {   0,
        1,    1,    1,    2,    3,    1,    1,    4,    1,    1,
        5,    1,    1,    1,    1,    6,    7,    1,    1,    1,
        8,    1,    1,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    1,    1
    } ;

static yyconst flex_int16_t yy_base[436] =
    {   0,
        0,    0,  849,  848,  850,  849,  852,  851,  854,  861,
       54,   56,  861,    0,  861,  861,  861,  861,  861,  861,
      861,  861,  838,  841,   45,  830,  861,   42,  861,  829,
      861,   45,   49,   54,   58,   56,   72,  833,   83,   86,
       63,   67,   90,   53,  105,  107,  106,  120,   51,  101,
      861,  861,    0,   55,    0,  840,    0,  843,  106,    0,
      861,  861,  829,   61,  824,  861,  861,  861,  861,  839,
      827,   88,  124,  130,  132,  125,  826,  129,  133,  136,
       52,  138,  148,  140,  142,  145,  149,  152,  151,  159,
      162,  169,  165,  825,  172,  824,  173,  170,  175,  179,

      176,  177,  823,  822,  180,  182,  184,  200,  201,  195,
      189,  202,  204,  207,  205,  210,  218,  220,  213,  215,
      223,  230,  238,  217,    0,  240,  244,  861,    0,  829,
        0,  832,  818,  781,    0,  817,  816,  233,  237,  243,
      248,  251,  246,  252,  255,  257,  258,  262,  264,  263,
      265,  267,  266,  269,  273,  270,  815,  274,  275,  287,
      814,  290,  292,  291,  293,  294,  297,  300,  304,  298,
      307,  313,  308,  309,  317,  813,  314,  315,  323,  318,
      324,  328,  331,  332,  333,  812,  336,  811,  338,  810,
      340,  339,  342,  344,  343,  341,  347,  346,  348,  349,

      359,  773,    0,  356,  369,  370,  360,  808,  371,  807,
      372,  375,  376,  378,  379,  380,  382,  383,  388,  393,
      394,  806,  396,  397,  805,  398,  804,  399,  400,  803,
      403,  404,  408,  413,  405,  802,  415,  801,  800,  799,
      798,  406,  797,  796,  416,  417,  420,  795,  422,  418,
      423,  425,  424,  426,  439,  429,  437,  440,  794,  446,
      450,  453,  454,  455,  457,  458,  459,  460,  793,  757,
      461,  791,  463,  464,  466,  790,  467,  468,  473,  474,
      789,  475,  476,  477,  478,  480,  485,  486,  788,  787,
      786,  489,  785,  491,  784,  498,  493,  494,  783,  499,

      504,  509,  511,  513,  516,  514,  517,  782,  520,  519,
      781,  521,  523,  527,  525,  528,  526,  529,  780,  779,
      780,  776,  773,  530,  533,  535,  772,  534,  771,  770,
      541,  769,  550,  760,  543,  548,  551,  753,  552,  736,
      554,  730,  556,  557,  723,  558,  566,  563,  693,  692,
      569,  572,  565,  578,  691,  574,  690,  689,  567,  585,
      588,  688,  687,  685,  571,  589,  591,  683,  592,  593,
      681,  680,  595,  596,  679,  597,  678,  599,  604,  602,
      605,  608,  676,  606,  675,  674,  609,  673,  607,  610,
      614,  670,  620,  623,  668,  628,  667,  630,  665,  664,

      625,  663,  629,  112,  627,  626,  631,  632,  647,  633,
      636,  637,  644,  650,  110,  652,  659,  657,  660,  661,
      662,   57,  861,  710,  719,  728,  731,  734,  738,  747,
      756,  765,  774,  781,  784
    } ;

static yyconst flex_int16_t yy_def[436] =
    {   0,
      423,    1,  424,  424,  425,  425,  426,  426,  423,  423,
      423,  423,  423,  427,  423,  423,  423,  423,  423,  423,
      423,  423,  423,  423,  423,  428,  423,  423,  423,  423,
      423,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      423,  423,  430,  431,  432,  423,  433,  423,  423,  427,
      423,  423,  423,  423,  428,  423,  423,  423,  423,  434,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,

      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  430,  431,  431,  423,  432,  423,
      433,  423,  423,  423,  435,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,

      429,  423,  435,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  423,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,

      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      423,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,

      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,  429,  429,  429,  429,  429,  429,  429,  429,
      429,  429,    0,  423,  423,  423,  423,  423,  423,  423,
      423,  423,  423,  423,  423
    } ;

static yyconst flex_int16_t yy_nxt[917] =
    {   0,
       10,   11,   12,   13,   10,   14,   15,   16,   17,   18,
       19,   20,   21,   22,   23,   24,   25,   26,   27,   28,
       29,   30,   31,   32,   33,   34,   35,   36,   37,   38,
       38,   39,   38,   38,   40,   41,   42,   43,   44,   38,
       45,   46,   47,   48,   49,   50,   38,   38,   38,   38,
       38,   38,   38,   51,   52,   59,   59,   59,   59,   63,
       70,   64,   67,   68,   70,  127,   70,   70,   70,   70,
      128,   70,   70,   70,  122,   63,   74,   64,   70,  149,
       75,   72,   70,   76,   78,   83,   73,   70,   79,   84,
       86,   80,   87,  108,   81,   85,   77,   82,   70,   89,

      100,   70,   88,   70,  101,   70,   90,   59,   59,   91,
      102,   94,   92,   97,  136,   93,   70,   98,  103,   95,
       70,   70,   70,   99,   96,   70,  104,   70,  105,  117,
      106,  123,  109,  107,  112,   70,  118,  113,  124,   70,
       70,  110,  111,  119,   70,   70,  114,   70,   70,  137,
      115,   70,  143,   70,  116,   70,  120,   70,  121,  139,
       70,  140,  142,   70,   70,  138,   70,   70,  141,  155,
      144,  146,  147,  151,   70,  157,  145,   70,  150,  148,
       70,  154,  152,  158,   70,   70,  156,   70,   70,  153,
       70,   70,   70,  159,   70,   70,  160,   70,  164,   70,

      169,  163,  161,  168,   70,  171,  162,  174,  175,  167,
       70,  173,  170,  165,  166,   70,   70,   70,  172,   70,
       70,  182,   70,  183,  179,   70,  176,  187,   70,  189,
       70,  177,   70,   70,  184,   70,  185,  178,   70,  180,
      190,  188,  192,  181,  186,   70,  195,  193,   70,  197,
      423,  191,   70,   70,  127,  423,  196,  201,   70,  128,
      204,   70,  194,   70,  198,  199,   70,   70,  205,  200,
       70,  207,   70,   70,  206,  208,  209,   70,   70,   70,
       70,   70,   70,  215,   70,   70,  210,  217,   70,   70,
       70,  222,  213,  211,  221,  214,  212,  225,  216,  220,

      228,  226,   70,  218,  219,   70,   70,   70,   70,   70,
      229,  223,   70,   70,  224,   70,  227,  231,  232,   70,
      233,  235,   70,   70,   70,  230,  237,  238,   70,   70,
       70,  236,   70,   70,  241,  234,  240,  239,   70,   70,
      247,  242,  243,   70,  245,  244,   70,   70,   70,  248,
      246,   70,  249,   70,   70,   70,   70,   70,   70,   70,
      254,   70,   70,   70,   70,  252,  257,  250,  260,  261,
      265,   70,  264,  258,   70,   70,  255,  251,  259,  256,
      262,  253,  263,  268,   70,   70,   70,   70,  267,  266,
       70,   70,  269,   70,   70,   70,  271,   70,   70,  276,

      274,  279,  280,   70,  275,  272,  273,  278,   70,   70,
      283,   70,   70,   70,   70,   70,  285,  277,   70,   70,
       70,   70,  281,   70,  282,  284,  289,  287,   70,  290,
       70,   70,   70,   70,  296,   70,  286,   70,   70,   70,
       70,   70,  291,  298,   70,  292,  288,  301,  294,  305,
      293,  307,   70,  295,   70,   70,  299,  297,  303,  300,
      310,   70,  306,  302,  304,   70,  308,  311,   70,   70,
       70,  309,   70,   70,   70,   70,   70,  312,   70,   70,
      313,   70,   70,   70,  316,  318,  319,  320,   70,   70,
       70,   70,   70,   70,  326,   70,  314,  315,  328,  317,

       70,   70,  330,  322,   70,  323,   70,  334,   70,   70,
      327,  324,  331,   70,   70,  325,  329,  332,  333,   70,
      337,  335,  336,  340,   70,  339,   70,  342,   70,   70,
      343,   70,   70,  338,   70,   70,   70,  341,   70,  347,
       70,   70,   70,   70,   70,   70,  353,  345,   70,   70,
       70,  344,  355,  357,  348,  346,   70,  352,   70,  349,
      350,  351,  354,   70,  356,   70,   70,   70,  365,   70,
      358,   70,   70,   70,  360,  361,  362,  364,   70,  359,
       70,   70,   70,  363,   70,  366,   70,   70,  367,   70,
      369,  373,  368,   70,  374,  376,  375,  371,  372,  370,

       70,  379,  378,   70,   70,  377,   70,   70,   70,  380,
       70,   70,   70,  383,   70,  382,  381,   70,  386,   70,
       70,   70,   70,   70,   70,   70,  391,  385,  388,   70,
      392,  384,  389,  387,  395,   70,  397,  390,   70,  393,
       70,   70,   70,   70,   70,   70,   70,   70,   70,  398,
      402,   70,   70,  394,  400,  396,  403,  399,  404,   70,
      406,  405,   70,  413,  412,   70,  409,   70,  408,  401,
      407,  411,   70,  414,   70,   70,   70,   70,   70,   70,
       70,  410,   70,   70,  415,   70,  418,  417,   70,   70,
       70,   70,  419,   70,   70,   70,   70,  420,   70,  416,

       70,  421,   70,   70,   70,   70,   70,   70,   70,  422,
       53,   53,   53,   53,   53,   53,   53,   53,   53,   55,
       55,   55,   55,   55,   55,   55,   55,   55,   57,   57,
       57,   57,   57,   57,   57,   57,   57,   60,   70,   60,
       65,   65,   65,   71,   71,   70,   71,  125,  125,  125,
      125,   70,  125,  125,  125,  125,  126,  126,  126,  126,
      126,  126,  126,  126,  126,  129,  129,  129,   70,  129,
      129,  129,  129,  129,  131,   70,  131,  131,  131,  131,
      131,  131,  131,  135,   70,   70,   70,   70,   70,  135,
      203,   70,  203,  135,   70,   70,   70,   70,   70,   70,

       70,   70,   70,   70,   70,   70,   70,  321,   70,   70,
       70,   70,   70,   70,   70,   70,   70,   70,   70,   70,
       70,   70,   70,   70,  270,   70,   70,   70,   70,   70,
       70,   70,   70,  202,  133,  132,  130,   70,   70,   70,
       70,   70,   70,  134,  423,  133,  132,  130,   70,   69,
       66,   62,   61,  423,   58,   58,   56,   56,   54,   54,
        9,  423,  423,  423,  423,  423,  423,  423,  423,  423,
      423,  423,  423,  423,  423,  423,  423,  423,  423,  423,
      423,  423,  423,  423,  423,  423,  423,  423,  423,  423,
      423,  423,  423,  423,  423,  423,  423,  423,  423,  423,

      423,  423,  423,  423,  423,  423,  423,  423,  423,  423,
      423,  423,  423,  423,  423,  423
    } ;

static yyconst flex_int16_t yy_chk[917] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,   11,   11,   12,   12,   25,
       32,   25,   28,   28,   33,   54,   49,   81,   44,   34,
       54,   36,  422,   35,   49,   64,   33,   64,   41,   81,
       33,   32,   42,   33,   34,   35,   32,   37,   34,   35,
       36,   34,   36,   44,   34,   35,   33,   34,   39,   37,

       41,   40,   36,   72,   42,   43,   37,   59,   59,   37,
       42,   39,   37,   40,   72,   37,   50,   40,   43,   39,
       45,   47,   46,   40,   39,  415,   43,  404,   43,   47,
       43,   50,   45,   43,   46,   48,   47,   46,   50,   73,
       76,   45,   45,   47,   78,   74,   46,   75,   79,   73,
       46,   80,   78,   82,   46,   84,   48,   85,   48,   74,
       86,   75,   76,   83,   87,   73,   89,   88,   75,   85,
       79,   80,   80,   83,   90,   87,   79,   91,   82,   80,
       93,   84,   83,   88,   92,   98,   86,   95,   97,   83,
       99,  101,  102,   89,  100,  105,   90,  106,   95,  107,

       99,   93,   91,   98,  111,  100,   92,  105,  106,   97,
      110,  102,   99,   95,   95,  108,  109,  112,  101,  113,
      115,  110,  114,  111,  109,  116,  107,  113,  119,  115,
      120,  108,  124,  117,  111,  118,  112,  108,  121,  109,
      115,  114,  117,  109,  112,  122,  120,  118,  138,  121,
      126,  116,  139,  123,  127,  126,  120,  124,  140,  127,
      138,  143,  119,  141,  122,  123,  142,  144,  139,  123,
      145,  141,  146,  147,  140,  142,  142,  148,  150,  149,
      151,  153,  152,  147,  154,  156,  143,  149,  155,  158,
      159,  153,  146,  144,  152,  146,  145,  156,  148,  151,

      159,  156,  160,  150,  150,  162,  164,  163,  165,  166,
      160,  154,  167,  170,  155,  168,  158,  163,  164,  169,
      165,  166,  171,  173,  174,  162,  167,  168,  172,  177,
      178,  166,  175,  180,  171,  165,  170,  169,  179,  181,
      178,  172,  173,  182,  175,  174,  183,  184,  185,  179,
      177,  187,  180,  189,  192,  191,  196,  193,  195,  194,
      185,  198,  197,  199,  200,  183,  191,  181,  194,  194,
      197,  204,  196,  192,  201,  207,  187,  182,  193,  189,
      194,  184,  195,  200,  205,  206,  209,  211,  199,  198,
      212,  213,  201,  214,  215,  216,  204,  217,  218,  211,

      207,  214,  215,  219,  209,  205,  206,  213,  220,  221,
      218,  223,  224,  226,  228,  229,  220,  212,  231,  232,
      235,  242,  216,  233,  217,  219,  226,  223,  234,  228,
      237,  245,  246,  250,  235,  247,  221,  249,  251,  253,
      252,  254,  229,  242,  256,  231,  224,  247,  233,  252,
      232,  254,  257,  234,  255,  258,  245,  237,  250,  246,
      257,  260,  253,  249,  251,  261,  255,  258,  262,  263,
      264,  256,  265,  266,  267,  268,  271,  260,  273,  274,
      261,  275,  277,  278,  264,  266,  267,  268,  279,  280,
      282,  283,  284,  285,  277,  286,  262,  263,  279,  265,

      287,  288,  282,  271,  292,  273,  294,  286,  297,  298,
      278,  274,  283,  296,  300,  275,  280,  284,  285,  301,
      292,  287,  288,  297,  302,  296,  303,  300,  304,  306,
      301,  305,  307,  294,  310,  309,  312,  298,  313,  305,
      315,  317,  314,  316,  318,  324,  313,  303,  325,  328,
      326,  302,  315,  317,  306,  304,  331,  312,  335,  307,
      309,  310,  314,  336,  316,  333,  337,  339,  335,  341,
      318,  343,  344,  346,  325,  326,  328,  333,  348,  324,
      353,  347,  359,  331,  351,  336,  365,  352,  337,  356,
      341,  347,  339,  354,  348,  352,  351,  344,  346,  343,

      360,  356,  354,  361,  366,  353,  367,  369,  370,  359,
      373,  374,  376,  365,  378,  361,  360,  380,  369,  379,
      381,  384,  389,  382,  387,  390,  378,  367,  373,  391,
      379,  366,  374,  370,  382,  393,  387,  376,  394,  380,
      401,  406,  405,  396,  403,  398,  407,  408,  410,  389,
      394,  411,  412,  381,  391,  384,  396,  390,  398,  413,
      403,  401,  409,  411,  410,  414,  407,  416,  406,  393,
      405,  409,  418,  412,  417,  419,  420,  421,  402,  400,
      399,  408,  397,  395,  413,  392,  417,  416,  388,  386,
      385,  383,  418,  377,  375,  372,  371,  419,  368,  414,

      364,  420,  363,  362,  358,  357,  355,  350,  349,  421,
      424,  424,  424,  424,  424,  424,  424,  424,  424,  425,
      425,  425,  425,  425,  425,  425,  425,  425,  426,  426,
      426,  426,  426,  426,  426,  426,  426,  427,  345,  427,
      428,  428,  428,  429,  429,  342,  429,  430,  430,  430,
      430,  340,  430,  430,  430,  430,  431,  431,  431,  431,
      431,  431,  431,  431,  431,  432,  432,  432,  338,  432,
      432,  432,  432,  432,  433,  334,  433,  433,  433,  433,
      433,  433,  433,  434,  332,  330,  329,  327,  323,  434,
      435,  322,  435,  321,  320,  319,  311,  308,  299,  295,

      293,  291,  290,  289,  281,  276,  272,  270,  269,  259,
      248,  244,  243,  241,  240,  239,  238,  236,  230,  227,
      225,  222,  210,  208,  202,  190,  188,  186,  176,  161,
      157,  137,  136,  134,  133,  132,  130,  104,  103,   96,
       94,   77,   71,   70,   65,   63,   58,   56,   38,   30,
       26,   24,   23,    9,    8,    7,    6,    5,    4,    3,
      423,  423,  423,  423,  423,  423,  423,  423,  423,  423,
      423,  423,  423,  423,  423,  423,  423,  423,  423,  423,
      423,  423,  423,  423,  423,  423,  423,  423,  423,  423,
      423,  423,  423,  423,  423,  423,  423,  423,  423,  423,

      423,  423,  423,  423,  423,  423,  423,  423,  423,  423,
      423,  423,  423,  423,  423,  423
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "pars0lex.l"
/*****************************************************************************

Copyright (c) 1997, 2011, Oracle and/or its affiliates. All Rights Reserved.

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation; version 2 of the License.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Suite 500, Boston, MA 02110-1335 USA

*****************************************************************************/
/******************************************************
SQL parser lexical analyzer: input file for the GNU Flex lexer generator

The InnoDB parser is frozen because MySQL takes care of SQL parsing.
Therefore we normally keep the InnoDB parser C files as they are, and do
not automatically generate them from pars0grm.y and pars0lex.l.

How to make the InnoDB parser and lexer C files:

1. Run ./make_flex.sh to generate lexer files.

2. Run ./make_bison.sh to generate parser files.

These instructions seem to work at least with bison-1.875d and flex-2.5.31 on
Linux.

Created 12/14/1997 Heikki Tuuri
*******************************************************/
#define YY_NO_INPUT 1
#define YY_NO_UNISTD_H 1
#line 53 "pars0lex.l"
#define YYSTYPE que_node_t*

#include "univ.i"
#include "pars0pars.h"
#include "pars0grm.h"
#include "pars0sym.h"
#include "mem0mem.h"
#include "os0proc.h"

#define malloc(A)	ut_malloc(A)
#define free(A)		ut_free(A)
#define realloc(P, A)	ut_realloc(P, A)
#define exit(A) 	ut_error

#define YY_INPUT(buf, result, max_size) \
	(result = pars_get_lex_chars(buf, max_size))

/* String buffer for removing quotes */
static ulint	stringbuf_len_alloc = 0; /* Allocated length */
static ulint	stringbuf_len = 0; /* Current length */
static char*	stringbuf; /* Start of buffer */
/** Appends a string to the buffer. */
static
void
string_append(
/*==========*/
	const char*	str,	/*!< in: string to be appended */
	ulint		len)	/*!< in: length of the string */
{
	if (stringbuf == NULL) {
		stringbuf = static_cast<char*>(malloc(1));
		stringbuf_len_alloc = 1;
	}

	if (stringbuf_len + len > stringbuf_len_alloc) {
		while (stringbuf_len + len > stringbuf_len_alloc) {
			stringbuf_len_alloc <<= 1;
		}

		stringbuf = static_cast<char*>(
			realloc(stringbuf, stringbuf_len_alloc));
	}

	memcpy(stringbuf + stringbuf_len, str, len);
	stringbuf_len += len;
}




#line 887 "lexyy.cc"

#define INITIAL 0
#define comment 1
#define quoted 2
#define id 3

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

__attribute__((unused)) static int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

yy_size_t yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( yytext, yyleng, 1, yyout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		yy_size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;

#line 112 "pars0lex.l"


#line 1073 "lexyy.cc"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 424 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 423 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 114 "pars0lex.l"
{
			yylval = sym_tab_add_int_lit(pars_sym_tab_global,
								atoi(yytext));
			return(PARS_INT_LIT);
}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 120 "pars0lex.l"
{
			ut_error;	/* not implemented */

			return(PARS_FLOAT_LIT);
}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 126 "pars0lex.l"
{
			ulint	type;

			yylval = sym_tab_add_bound_lit(pars_sym_tab_global,
				yytext + 1, &type);

			return((int) type);
}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 135 "pars0lex.l"
{
			yylval = sym_tab_add_bound_id(pars_sym_tab_global,
				yytext + 1);

			return(PARS_ID_TOKEN);
}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 142 "pars0lex.l"
{
/* Quoted character string literals are handled in an explicit
start state 'quoted'.  This state is entered and the buffer for
the scanned string is emptied upon encountering a starting quote.

In the state 'quoted', only two actions are possible (defined below). */
			BEGIN(quoted);
			stringbuf_len = 0;
}
	YY_BREAK
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 151 "pars0lex.l"
{
			/* Got a sequence of characters other than "'":
			append to string buffer */
			string_append(yytext, yyleng);
}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 156 "pars0lex.l"
{
			/* Got a sequence of "'" characters:
			append half of them to string buffer,
			as "''" represents a single "'".
			We apply truncating division,
			so that "'''" will result in "'". */

			string_append(yytext, yyleng / 2);

			/* If we got an odd number of quotes, then the
			last quote we got is the terminating quote.
			At the end of the string, we return to the
			initial start state and report the scanned
			string literal. */

			if (yyleng % 2) {
				BEGIN(INITIAL);
				yylval = sym_tab_add_str_lit(
					pars_sym_tab_global,
					(byte*) stringbuf, stringbuf_len);
				return(PARS_STR_LIT);
			}
}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 180 "pars0lex.l"
{
/* Quoted identifiers are handled in an explicit start state 'id'.
This state is entered and the buffer for the scanned string is emptied
upon encountering a starting quote.

In the state 'id', only two actions are possible (defined below). */
			BEGIN(id);
			stringbuf_len = 0;
}
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 189 "pars0lex.l"
{
			/* Got a sequence of characters other than '"':
			append to string buffer */
			string_append(yytext, yyleng);
}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 194 "pars0lex.l"
{
			/* Got a sequence of '"' characters:
			append half of them to string buffer,
			as '""' represents a single '"'.
			We apply truncating division,
			so that '"""' will result in '"'. */

			string_append(yytext, yyleng / 2);

			/* If we got an odd number of quotes, then the
			last quote we got is the terminating quote.
			At the end of the string, we return to the
			initial start state and report the scanned
			identifier. */

			if (yyleng % 2) {
				BEGIN(INITIAL);
				yylval = sym_tab_add_id(
					pars_sym_tab_global,
					(byte*) stringbuf, stringbuf_len);

				return(PARS_ID_TOKEN);
			}
}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 219 "pars0lex.l"
{
			yylval = sym_tab_add_null_lit(pars_sym_tab_global);

			return(PARS_NULL_LIT);
}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 225 "pars0lex.l"
{
			/* Implicit cursor name */
			yylval = sym_tab_add_str_lit(pars_sym_tab_global,
							(byte*) yytext, yyleng);
			return(PARS_SQL_TOKEN);
}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 232 "pars0lex.l"
{
			return(PARS_AND_TOKEN);
}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 236 "pars0lex.l"
{
			return(PARS_OR_TOKEN);
}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 240 "pars0lex.l"
{
			return(PARS_NOT_TOKEN);
}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 244 "pars0lex.l"
{
			return(PARS_PROCEDURE_TOKEN);
}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 248 "pars0lex.l"
{
			return(PARS_IN_TOKEN);
}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 252 "pars0lex.l"
{
			return(PARS_OUT_TOKEN);
}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 256 "pars0lex.l"
{
			return(PARS_BINARY_TOKEN);
}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 260 "pars0lex.l"
{
			return(PARS_BLOB_TOKEN);
}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 264 "pars0lex.l"
{
			return(PARS_INT_TOKEN);
}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 268 "pars0lex.l"
{
			return(PARS_INT_TOKEN);
}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 272 "pars0lex.l"
{
			return(PARS_FLOAT_TOKEN);
}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 276 "pars0lex.l"
{
			return(PARS_CHAR_TOKEN);
}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 280 "pars0lex.l"
{
			return(PARS_IS_TOKEN);
}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 284 "pars0lex.l"
{
			return(PARS_BEGIN_TOKEN);
}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 288 "pars0lex.l"
{
			return(PARS_END_TOKEN);
}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 292 "pars0lex.l"
{
			return(PARS_IF_TOKEN);
}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 296 "pars0lex.l"
{
			return(PARS_THEN_TOKEN);
}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 300 "pars0lex.l"
{
			return(PARS_ELSE_TOKEN);
}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 304 "pars0lex.l"
{
			return(PARS_ELSIF_TOKEN);
}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 308 "pars0lex.l"
{
			return(PARS_LOOP_TOKEN);
}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 312 "pars0lex.l"
{
			return(PARS_WHILE_TOKEN);
}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 316 "pars0lex.l"
{
			return(PARS_RETURN_TOKEN);
}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 320 "pars0lex.l"
{
			return(PARS_SELECT_TOKEN);
}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 324 "pars0lex.l"
{
			return(PARS_SUM_TOKEN);
}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 328 "pars0lex.l"
{
			return(PARS_COUNT_TOKEN);
}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 332 "pars0lex.l"
{
			return(PARS_DISTINCT_TOKEN);
}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 336 "pars0lex.l"
{
			return(PARS_FROM_TOKEN);
}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 340 "pars0lex.l"
{
			return(PARS_WHERE_TOKEN);
}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 344 "pars0lex.l"
{
			return(PARS_FOR_TOKEN);
}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 348 "pars0lex.l"
{
			return(PARS_READ_TOKEN);
}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 352 "pars0lex.l"
{
			return(PARS_ORDER_TOKEN);
}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 356 "pars0lex.l"
{
			return(PARS_BY_TOKEN);
}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 360 "pars0lex.l"
{
			return(PARS_ASC_TOKEN);
}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 364 "pars0lex.l"
{
			return(PARS_DESC_TOKEN);
}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 368 "pars0lex.l"
{
			return(PARS_INSERT_TOKEN);
}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 372 "pars0lex.l"
{
			return(PARS_INTO_TOKEN);
}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 376 "pars0lex.l"
{
			return(PARS_VALUES_TOKEN);
}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 380 "pars0lex.l"
{
			return(PARS_UPDATE_TOKEN);
}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 384 "pars0lex.l"
{
			return(PARS_SET_TOKEN);
}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 388 "pars0lex.l"
{
			return(PARS_DELETE_TOKEN);
}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 392 "pars0lex.l"
{
			return(PARS_CURRENT_TOKEN);
}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 396 "pars0lex.l"
{
			return(PARS_OF_TOKEN);
}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 400 "pars0lex.l"
{
			return(PARS_CREATE_TOKEN);
}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 404 "pars0lex.l"
{
			return(PARS_TABLE_TOKEN);
}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 408 "pars0lex.l"
{
			return(PARS_COMPACT_TOKEN);
}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 412 "pars0lex.l"
{
			return(PARS_BLOCK_SIZE_TOKEN);
}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 416 "pars0lex.l"
{
			return(PARS_INDEX_TOKEN);
}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 420 "pars0lex.l"
{
			return(PARS_UNIQUE_TOKEN);
}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 424 "pars0lex.l"
{
			return(PARS_CLUSTERED_TOKEN);
}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 428 "pars0lex.l"
{
			return(PARS_DOES_NOT_FIT_IN_MEM_TOKEN);
}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 432 "pars0lex.l"
{
			return(PARS_ON_TOKEN);
}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 436 "pars0lex.l"
{
			return(PARS_DECLARE_TOKEN);
}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 440 "pars0lex.l"
{
			return(PARS_CURSOR_TOKEN);
}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 444 "pars0lex.l"
{
			return(PARS_OPEN_TOKEN);
}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 448 "pars0lex.l"
{
			return(PARS_FETCH_TOKEN);
}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 452 "pars0lex.l"
{
			return(PARS_CLOSE_TOKEN);
}
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 456 "pars0lex.l"
{
			return(PARS_NOTFOUND_TOKEN);
}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 460 "pars0lex.l"
{
			return(PARS_TO_CHAR_TOKEN);
}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 464 "pars0lex.l"
{
			return(PARS_TO_NUMBER_TOKEN);
}
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 468 "pars0lex.l"
{
			return(PARS_TO_BINARY_TOKEN);
}
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 472 "pars0lex.l"
{
			return(PARS_BINARY_TO_NUMBER_TOKEN);
}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 476 "pars0lex.l"
{
			return(PARS_SUBSTR_TOKEN);
}
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 480 "pars0lex.l"
{
			return(PARS_REPLSTR_TOKEN);
}
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 484 "pars0lex.l"
{
			return(PARS_CONCAT_TOKEN);
}
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 488 "pars0lex.l"
{
			return(PARS_INSTR_TOKEN);
}
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 492 "pars0lex.l"
{
			return(PARS_LENGTH_TOKEN);
}
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 496 "pars0lex.l"
{
			return(PARS_SYSDATE_TOKEN);
}
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 500 "pars0lex.l"
{
			return(PARS_PRINTF_TOKEN);
}
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 504 "pars0lex.l"
{
			return(PARS_ASSERT_TOKEN);
}
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 508 "pars0lex.l"
{
			return(PARS_RND_TOKEN);
}
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 512 "pars0lex.l"
{
			return(PARS_RND_STR_TOKEN);
}
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 516 "pars0lex.l"
{
			return(PARS_ROW_PRINTF_TOKEN);
}
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 520 "pars0lex.l"
{
			return(PARS_COMMIT_TOKEN);
}
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 524 "pars0lex.l"
{
			return(PARS_ROLLBACK_TOKEN);
}
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 528 "pars0lex.l"
{
			return(PARS_WORK_TOKEN);
}
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 532 "pars0lex.l"
{
			return(PARS_UNSIGNED_TOKEN);
}
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 536 "pars0lex.l"
{
			return(PARS_EXIT_TOKEN);
}
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 540 "pars0lex.l"
{
			return(PARS_FUNCTION_TOKEN);
}
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 544 "pars0lex.l"
{
			return(PARS_LOCK_TOKEN);
}
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 548 "pars0lex.l"
{
			return(PARS_SHARE_TOKEN);
}
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 552 "pars0lex.l"
{
			return(PARS_MODE_TOKEN);
}
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 556 "pars0lex.l"
{
                        return(PARS_LIKE_TOKEN);
}
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 560 "pars0lex.l"
{
			return(PARS_BIGINT_TOKEN);
}
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 564 "pars0lex.l"
{
			yylval = sym_tab_add_id(pars_sym_tab_global,
							(byte*) yytext,
							ut_strlen(yytext));
			return(PARS_ID_TOKEN);
}
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 571 "pars0lex.l"
{
			yylval = sym_tab_add_id(pars_sym_tab_global,
							(byte*) yytext,
							ut_strlen(yytext));
			return(PARS_TABLE_NAME_TOKEN);
}
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 578 "pars0lex.l"
{
			return(PARS_DDOT_TOKEN);
}
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 582 "pars0lex.l"
{
			return(PARS_ASSIGN_TOKEN);
}
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 586 "pars0lex.l"
{
			return(PARS_LE_TOKEN);
}
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 590 "pars0lex.l"
{
			return(PARS_GE_TOKEN);
}
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 594 "pars0lex.l"
{
			return(PARS_NE_TOKEN);
}
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 598 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 603 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 608 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 613 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 618 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 623 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 628 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 633 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 638 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 643 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 648 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 653 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 658 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 663 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 668 "pars0lex.l"
{

			return((int)(*yytext));
}
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 673 "pars0lex.l"
BEGIN(comment); /* eat up comment */
	YY_BREAK
case 119:
/* rule 119 can match eol */
YY_RULE_SETUP
#line 675 "pars0lex.l"

	YY_BREAK
case 120:
/* rule 120 can match eol */
YY_RULE_SETUP
#line 676 "pars0lex.l"

	YY_BREAK
case 121:
YY_RULE_SETUP
#line 677 "pars0lex.l"
BEGIN(INITIAL);
	YY_BREAK
case 122:
/* rule 122 can match eol */
YY_RULE_SETUP
#line 679 "pars0lex.l"
/* eat up whitespace */
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 682 "pars0lex.l"
{
			fprintf(stderr,"Unrecognized character: %02x\n",
				*yytext);

			ut_error;

			return(0);
}
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 691 "pars0lex.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 2113 "lexyy.cc"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(comment):
case YY_STATE_EOF(quoted):
case YY_STATE_EOF(id):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char*)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void*) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char*) yyrealloc((void*) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;

	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 424 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 424 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 423);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;

	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char*) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 *
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 *
 */
    __attribute__((unused)) static void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 *
 * @return the allocated buffer state.
 */
    static YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char*) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 *
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void*) b->yy_ch_buf  );

	yyfree((void*) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;

	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;

	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 *
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;

	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**) yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**) yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 *
 */
int yyget_lineno  (void)
{

    return yylineno;
}

/** Get the input stream.
 *
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 *
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 *
 */
yy_size_t yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 *
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 *
 */
void yyset_lineno (int  line_number )
{

    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 *
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char*) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE*) 0;
    yyout = (FILE*) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
__attribute__((unused)) static int yylex_destroy  (void)
{

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void*) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char*) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void*) realloc( (char*) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char*) ptr );	/* see yyrealloc() for (char*) cast */
}

#define YYTABLES_NAME "yytables"

#line 691 "pars0lex.l"



/**********************************************************************
Release any resources used by the lexer. */
UNIV_INTERN
void
pars_lexer_close(void)
/*==================*/
{
	yylex_destroy();
	free(stringbuf);
	stringbuf = NULL;
	stringbuf_len_alloc = stringbuf_len = 0;
}

